pub struct A2ATaskExecutor { /* private fields */ }Expand description
The A2A task executor: polls for pending tasks and executes them via fighters.
Implementations
Sourceimpl A2ATaskExecutor
impl A2ATaskExecutor
Sourcepub fn new(ring: Arc<Ring>, tasks: Arc<DashMap<String, A2ATask>>) -> Self
pub fn new(ring: Arc<Ring>, tasks: Arc<DashMap<String, A2ATask>>) -> Self
Create a new executor that will poll the given task map and use the Ring to spawn fighters for execution.
Sourcepub fn with_poll_interval(
ring: Arc<Ring>,
tasks: Arc<DashMap<String, A2ATask>>,
poll_interval: Duration,
) -> Self
pub fn with_poll_interval( ring: Arc<Ring>, tasks: Arc<DashMap<String, A2ATask>>, poll_interval: Duration, ) -> Self
Create a new executor with a custom polling interval.
Sourcepub fn start(&mut self)
pub fn start(&mut self)
Start the background polling loop.
Spawns a tokio task that polls the DashMap every poll_interval for
Pending tasks. Each pending task is picked
up and executed in its own spawned task.
Sourcepub fn is_running(&self) -> bool
pub fn is_running(&self) -> bool
Returns true if the executor is currently running.