pub struct BudgetEnforcer { /* private fields */ }Expand description
Enforces spending limits by checking the metering engine before each LLM call. Supports per-fighter and global limits.
Implementations
Sourceimpl BudgetEnforcer
impl BudgetEnforcer
Sourcepub fn new(metering: Arc<MeteringEngine>) -> Self
pub fn new(metering: Arc<MeteringEngine>) -> Self
Create a new budget enforcer backed by the given metering engine.
Sourcepub fn set_fighter_limit(&self, fighter_id: FighterId, limit: BudgetLimit)
pub fn set_fighter_limit(&self, fighter_id: FighterId, limit: BudgetLimit)
Set a per-fighter budget limit.
Sourcepub fn remove_fighter_limit(&self, fighter_id: &FighterId)
pub fn remove_fighter_limit(&self, fighter_id: &FighterId)
Remove a per-fighter budget limit.
Sourcepub fn get_fighter_limit(&self, fighter_id: &FighterId) -> Option<BudgetLimit>
pub fn get_fighter_limit(&self, fighter_id: &FighterId) -> Option<BudgetLimit>
Get the per-fighter budget limit, if configured.
Sourcepub fn set_global_limit(&self, limit: BudgetLimit)
pub fn set_global_limit(&self, limit: BudgetLimit)
Set the global budget limit (applies to all fighters).
Uses std::sync::RwLock so this is safe from both sync and async contexts.
Sourcepub fn clear_global_limit(&self)
pub fn clear_global_limit(&self)
Remove the global budget limit.
Sourcepub fn get_global_limit(&self) -> Option<BudgetLimit>
pub fn get_global_limit(&self) -> Option<BudgetLimit>
Get the current global budget limit.
Sourcepub async fn check_budget(
&self,
fighter_id: &FighterId,
) -> PunchResult<BudgetVerdict>
pub async fn check_budget( &self, fighter_id: &FighterId, ) -> PunchResult<BudgetVerdict>
Check the budget for a specific fighter before an LLM call.
This checks both the per-fighter limit (if set) and the global limit (if set). The most restrictive verdict wins.
Sourcepub async fn get_fighter_status(
&self,
fighter_id: &FighterId,
) -> PunchResult<BudgetStatus>
pub async fn get_fighter_status( &self, fighter_id: &FighterId, ) -> PunchResult<BudgetStatus>
Get the current budget status for a fighter (for API responses).
Sourcepub async fn get_global_status(&self) -> PunchResult<BudgetStatus>
pub async fn get_global_status(&self) -> PunchResult<BudgetStatus>
Get the global budget status.