pub struct KernelConfigDiff {
pub rate_limit_changed: bool,
pub model_changed: bool,
pub channels_changed: Vec<String>,
pub mcp_servers_changed: Vec<String>,
pub memory_changed: bool,
pub requires_restart: Vec<String>,
}Expand description
Summary of what changed between two configs — used by callbacks to react to specific categories of changes.
Fields
rate_limit_changed: boolWhether rate limit settings changed.
model_changed: boolWhether the default model changed.
channels_changed: Vec<String>Channel names that were added, removed, or modified.
mcp_servers_changed: Vec<String>MCP server names that were added, removed, or modified.
memory_changed: boolWhether memory configuration changed.
requires_restart: Vec<String>Non-reloadable fields that changed (require restart).
Implementations
Sourceimpl KernelConfigDiff
impl KernelConfigDiff
Sourcepub fn has_reloadable_changes(&self) -> bool
pub fn has_reloadable_changes(&self) -> bool
Returns true if any reloadable field changed.