auction_select_winner

Function auction_select_winner 

pub fn auction_select_winner(bids: &[AuctionBid]) -> Option<&AuctionBid>
Run an auction: collect bids from fighters and select the winner.

The winning bid is the one with the best combination of lowest time estimate and highest confidence.