execute_auction

Function execute_auction 

pub async fn execute_auction(
    fighters: &[FighterId],
    task: &str,
    router: &MessageRouter,
    coordinator: FighterId,
    bids: &[AuctionBid],
    min_confidence: f64,
) -> PunchResult<Option<AuctionBid>>
Execute the auction pattern: announce a task to all capable fighters, collect bids, and award the task to the best bidder.