execute_chain_of_responsibility

Function execute_chain_of_responsibility 

pub async fn execute_chain_of_responsibility(
    chain: &[ChainHandler],
    task: &str,
    router: &MessageRouter,
    coordinator: FighterId,
) -> PunchResult<Option<(FighterId, usize, String)>>
Execute the chain of responsibility pattern by sending the task through handlers until one processes it. Each handler is asked via messaging whether it can handle the task (based on capabilities). The first capable handler processes it.