supervisor_handle_failure

Function supervisor_handle_failure 

pub fn supervisor_handle_failure(
    config: &mut SupervisorConfig,
    failed_worker: &FighterId,
) -> Vec<FighterId>
Handle a worker failure according to the supervisor strategy.

Returns the list of workers that should be restarted.