pub fn chain_find_handler(
chain: &[ChainHandler],
task: &str,
) -> Option<FighterId>Expand description
Determine which handler in the chain should handle a task.
Returns the first handler whose capabilities match any keyword in the task. If no handler matches, returns None.