pub fn supervisor_handle_failure(
config: &mut SupervisorConfig,
failed_worker: &FighterId,
) -> Vec<FighterId>Expand description
Handle a worker failure according to the supervisor strategy.
Returns the list of workers that should be restarted.